@@ -56,46 +56,40 @@ func TestUnpackRunLengthChunk(t *testing.T) {
 			//nolint:dupl
 			acks: []Acknowledgment{
 				{
-					TLCC:      0,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 0,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      1,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 1,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      2,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 2,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      3,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 3,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      4,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 4,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      5,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 5,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 			},
 			n:       6,
@@ -120,46 +114,40 @@ func TestUnpackRunLengthChunk(t *testing.T) {
 			start: 65534,
 			acks: []Acknowledgment{
 				{
-					TLCC:      65534,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(250 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 65534,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(250 * time.Microsecond),
 				},
 				{
-					TLCC:      65535,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(500 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 65535,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(500 * time.Microsecond),
 				},
 				{
-					TLCC:      0,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(750 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 0,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(750 * time.Microsecond),
 				},
 				{
-					TLCC:      1,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(1000 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 1,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(1000 * time.Microsecond),
 				},
 				{
-					TLCC:      2,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(1250 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 2,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(1250 * time.Microsecond),
 				},
 				{
-					TLCC:      3,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(1500 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 3,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(1500 * time.Microsecond),
 				},
 			},
 			n:       6,
@@ -178,46 +166,40 @@ func TestUnpackRunLengthChunk(t *testing.T) {
 			//nolint:dupl
 			acks: []Acknowledgment{
 				{
-					TLCC:      65534,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 65534,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      65535,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 65535,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      0,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 0,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      1,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 1,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      2,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 2,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      3,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 3,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 			},
 			n:       0,
@@ -241,14 +223,14 @@ func TestUnpackRunLengthChunk(t *testing.T) {
 				assert.NoError(t, fa.OnSent(time.Time{}, h, 0, attributes))
 			}
 
-			n, refTime, acks, err := fa.unpackRunLengthChunk(time.Time{}, tc.start, time.Time{}, &tc.chunk, tc.deltas)
+			n, refTime, acks, err := fa.unpackRunLengthChunk(tc.start, time.Time{}, &tc.chunk, tc.deltas)
 			assert.NoError(t, err)
 			assert.Len(t, acks, len(tc.acks))
 			assert.Equal(t, tc.n, n)
 			assert.Equal(t, tc.refTime, refTime)
 
 			for i, a := range acks {
-				assert.Equal(t, tc.sentTLCC[i], a.TLCC)
+				assert.Equal(t, tc.sentTLCC[i], a.SequenceNumber)
 			}
 			assert.Equal(t, tc.acks, acks)
 		})
@@ -305,46 +287,40 @@ func TestUnpackStatusVectorChunk(t *testing.T) {
 			//nolint:dupl
 			acks: []Acknowledgment{
 				{
-					TLCC:      0,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 0,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      1,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 1,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      2,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 2,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      3,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 3,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      4,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 4,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      5,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 5,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 			},
 			n:       6,
@@ -375,46 +351,40 @@ func TestUnpackStatusVectorChunk(t *testing.T) {
 			start: 65534,
 			acks: []Acknowledgment{
 				{
-					TLCC:      65534,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(250 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 65534,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(250 * time.Microsecond),
 				},
 				{
-					TLCC:      65535,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(500 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 65535,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(500 * time.Microsecond),
 				},
 				{
-					TLCC:      0,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(750 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 0,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(750 * time.Microsecond),
 				},
 				{
-					TLCC:      1,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(1000 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 1,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(1000 * time.Microsecond),
 				},
 				{
-					TLCC:      2,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{},
-					RTT:       0,
+					SequenceNumber: 2,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{},
 				},
 				{
-					TLCC:      3,
-					Size:      0,
-					Departure: time.Time{},
-					Arrival:   time.Time{}.Add(1250 * time.Microsecond),
-					RTT:       0,
+					SequenceNumber: 3,
+					Size:           0,
+					Departure:      time.Time{},
+					Arrival:        time.Time{}.Add(1250 * time.Microsecond),
 				},
 			},
 			n:       5,
@@ -438,14 +408,14 @@ func TestUnpackStatusVectorChunk(t *testing.T) {
 				assert.NoError(t, fa.OnSent(time.Time{}, h, 0, attributes))
 			}
 
-			n, refTime, acks, err := fa.unpackStatusVectorChunk(time.Time{}, tc.start, time.Time{}, &tc.chunk, tc.deltas)
+			n, refTime, acks, err := fa.unpackStatusVectorChunk(tc.start, time.Time{}, &tc.chunk, tc.deltas)
 			assert.NoError(t, err)
 			assert.Len(t, acks, len(tc.acks))
 			assert.Equal(t, tc.n, n)
 			assert.Equal(t, tc.refTime, refTime)
 
 			for i, a := range acks {
-				assert.Equal(t, tc.sentTLCC[i], a.TLCC)
+				assert.Equal(t, tc.sentTLCC[i], a.SequenceNumber)
 			}
 			assert.Equal(t, tc.acks, acks)
 		})
@@ -559,55 +529,49 @@ func TestFeedbackAdapterTWCC(t *testing.T) {
 		assert.Len(t, results, 22)
 
 		assert.Contains(t, results, Acknowledgment{
-			TLCC:      0,
-			Size:      headers[0].MarshalSize() + 1200,
-			Departure: t0,
-			Arrival:   t0.Add(4 * time.Microsecond),
-			RTT:       0,
+			SequenceNumber: 0,
+			Size:           headers[0].MarshalSize() + 1200,
+			Departure:      t0,
+			Arrival:        t0.Add(4 * time.Microsecond),
 		})
 
 		assert.Contains(t, results, Acknowledgment{
-			TLCC:      1,
-			Size:      headers[1].MarshalSize() + 1200,
-			Departure: t0,
-			Arrival:   t0.Add(104 * time.Microsecond),
-			RTT:       0,
+			SequenceNumber: 1,
+			Size:           headers[1].MarshalSize() + 1200,
+			Departure:      t0,
+			Arrival:        t0.Add(104 * time.Microsecond),
 		})
 
 		for i := uint16(2); i < 7; i++ {
 			assert.Contains(t, results, Acknowledgment{
-				TLCC:      i,
-				Size:      headers[i].MarshalSize() + 1200,
-				Departure: t0,
-				Arrival:   time.Time{},
-				RTT:       0,
+				SequenceNumber: i,
+				Size:           headers[i].MarshalSize() + 1200,
+				Departure:      t0,
+				Arrival:        time.Time{},
 			})
 		}
 
 		assert.Contains(t, results, Acknowledgment{
-			TLCC:      7,
-			Size:      headers[7].MarshalSize() + 1200,
-			Departure: t0,
-			Arrival:   t0.Add(116 * time.Microsecond),
-			RTT:       0,
+			SequenceNumber: 7,
+			Size:           headers[7].MarshalSize() + 1200,
+			Departure:      t0,
+			Arrival:        t0.Add(116 * time.Microsecond),
 		})
 
 		for i := uint16(8); i < 21; i++ {
 			assert.Contains(t, results, Acknowledgment{
-				TLCC:      i,
-				Size:      headers[i].MarshalSize() + 1200,
-				Departure: t0,
-				Arrival:   time.Time{},
-				RTT:       0,
+				SequenceNumber: i,
+				Size:           headers[i].MarshalSize() + 1200,
+				Departure:      t0,
+				Arrival:        time.Time{},
 			})
 		}
 
 		assert.Contains(t, results, Acknowledgment{
-			TLCC:      21,
-			Size:      headers[21].MarshalSize() + 1200,
-			Departure: t0,
-			Arrival:   t0.Add(120 * time.Microsecond),
-			RTT:       0,
+			SequenceNumber: 21,
+			Size:           headers[21].MarshalSize() + 1200,
+			Departure:      t0,
+			Arrival:        t0.Add(120 * time.Microsecond),
 		})
 	})
 
@@ -697,18 +661,16 @@ func TestFeedbackAdapterTWCC(t *testing.T) {
 		assert.NotEmpty(t, results)
 		assert.Len(t, results, 7)
 		assert.Contains(t, results, Acknowledgment{
-			TLCC:      65535,
-			Size:      pkt65535.Header.MarshalSize() + 1200,
-			Departure: t0,
-			Arrival:   t0.Add(4 * time.Microsecond),
-			RTT:       0,
+			SequenceNumber: 65535,
+			Size:           pkt65535.Header.MarshalSize() + 1200,
+			Departure:      t0,
+			Arrival:        t0.Add(4 * time.Microsecond),
 		})
 		assert.Contains(t, results, Acknowledgment{
-			TLCC:      0,
-			Size:      pkt0.Header.MarshalSize() + 1200,
-			Departure: t0,
-			Arrival:   t0.Add(8 * time.Microsecond),
-			RTT:       0,
+			SequenceNumber: 0,
+			Size:           pkt0.Header.MarshalSize() + 1200,
+			Departure:      t0,
+			Arrival:        t0.Add(8 * time.Microsecond),
 		})
 	})
 
@@ -765,20 +727,18 @@ func TestFeedbackAdapterTWCC(t *testing.T) {
 		assert.Len(t, results, 7)
 		for i := uint16(0); i < 3; i++ {
 			assert.Contains(t, results, Acknowledgment{
-				TLCC:      i,
-				Size:      headers[i].MarshalSize() + 1200,
-				Departure: t0,
-				Arrival:   t0.Add(time.Duration((i + 1)) * 4 * time.Microsecond),
-				RTT:       0,
+				SequenceNumber: i,
+				Size:           headers[i].MarshalSize() + 1200,
+				Departure:      t0,
+				Arrival:        t0.Add(time.Duration((i + 1)) * 4 * time.Microsecond),
 			})
 		}
 		for i := uint16(3); i < 7; i++ {
 			assert.Contains(t, results, Acknowledgment{
-				TLCC:      i,
-				Size:      headers[i].MarshalSize() + 1200,
-				Departure: t0,
-				Arrival:   time.Time{},
-				RTT:       0,
+				SequenceNumber: i,
+				Size:           headers[i].MarshalSize() + 1200,
+				Departure:      t0,
+				Arrival:        time.Time{},
 			})
 		}
 	})
