@@ -20,12 +20,11 @@ func newArrivalGroupAccumulator() *arrivalGroupAccumulator {
 	}
 }
 
-func (a *arrivalGroupAccumulator) run(in <-chan cc.Acknowledgment) <-chan arrivalGroup {
-	out := make(chan arrivalGroup)
-	go func() {
-		init := false
-		group := arrivalGroup{}
-		for next := range in {
+func (a *arrivalGroupAccumulator) run(in <-chan []cc.Acknowledgment, agWriter func(arrivalGroup)) {
+	init := false
+	group := arrivalGroup{}
+	for acks := range in {
+		for _, next := range acks {
 			if !init {
 				group.add(next)
 				init = true
@@ -47,12 +46,25 @@ func (a *arrivalGroupAccumulator) run(in <-chan cc.Acknowledgment) <-chan arriva
 					continue
 				}
 
-				out <- group
+				agWriter(group)
 				group = arrivalGroup{}
 				group.add(next)
 			}
 		}
-		close(out)
-	}()
-	return out
+	}
+}
+
+func interArrivalTimePkt(a arrivalGroup, b cc.Acknowledgment) time.Duration {
+	return b.Arrival.Sub(a.arrival)
+}
+
+func interDepartureTimePkt(a arrivalGroup, b cc.Acknowledgment) time.Duration {
+	if len(a.packets) == 0 {
+		return 0
+	}
+	return b.Departure.Sub(a.packets[len(a.packets)-1].Departure)
+}
+
+func interGroupDelayVariationPkt(a arrivalGroup, b cc.Acknowledgment) time.Duration {
+	return b.Arrival.Sub(a.arrival) - b.Departure.Sub(a.departure)
 }
