@@ -16,13 +16,12 @@ func newRateCalculator(window time.Duration) *rateCalculator {
 	}
 }
 
-func (c *rateCalculator) run(in <-chan cc.Acknowledgment) <-chan int {
-	out := make(chan int)
-	go func() {
-		var history []cc.Acknowledgment
-		init := false
-		sum := 0
-		for next := range in {
+func (c *rateCalculator) run(in <-chan []cc.Acknowledgment, onRateUpdate func(int)) {
+	var history []cc.Acknowledgment
+	init := false
+	sum := 0
+	for acks := range in {
+		for _, next := range acks {
 			if next.Arrival.IsZero() {
 				// Ignore packet if it didn't arrive
 				continue
@@ -35,7 +34,7 @@ func (c *rateCalculator) run(in <-chan cc.Acknowledgment) <-chan int {
 				// Don't know any timeframe here, only arrival of last packet,
 				// which is by definition in the window that ends with the last
 				// arrival time
-				out <- next.Size * 8
+				onRateUpdate(next.Size * 8)
 				continue
 			}
 
@@ -50,15 +49,13 @@ func (c *rateCalculator) run(in <-chan cc.Acknowledgment) <-chan int {
 			}
 			history = history[del:]
 			if len(history) == 0 {
-				out <- 0
+				onRateUpdate(0)
 				continue
 			}
 			dt := next.Arrival.Sub(history[0].Arrival)
 			bits := 8 * sum
 			rate := int(float64(bits) / dt.Seconds())
-			out <- rate
+			onRateUpdate(rate)
 		}
-		close(out)
-	}()
-	return out
+	}
 }
